org_flutter library

Classes

DecryptedContentSerializer
InheritedOrgSettings
Org
Display an Org Mode document with full interaction.
OrgBlock
#+begin_quote foo #+end_quote
OrgBlockWidget
An Org Mode block
A bracketed link, like
OrgCitation
A citation like cite:@key
OrgCoderefWidget
OrgCoderefWidgetState
OrgComment
OrgCommentWidget
An Org comment
OrgContent
A generic node that contains children
OrgContentGrammarDefinition
Content grammar definition
OrgContentParserDefinition
Content-level parser definition
OrgContentWidget
Generic Org Mode content
OrgController
Control behavior of an Org Mode document widget. Not needed if you are using the Org widget.
OrgControllerData
OrgDataNode
OrgDataNodeMap
A collection of temporary data about an Org Mode document used for display purposes.
OrgDateRangeTimestamp
OrgDecryptedContent
OrgDecryptedContentWidget
A widget representing content decrypted from an OrgPgpBlock
OrgDiaryTimestamp
OrgDocument
The top-level node representing a full Org document
OrgDocumentWidget
The root of the actual Org Mode document itself. Assumes that OrgRootWidget and OrgController are available in the build context. See the Org widget for a more user-friendly entrypoint.
OrgDrawer
A drawer, like
OrgDrawerWidget
An Org Mode drawer
OrgDynamicBlock
#+BEGIN: myblockfunc :parameter1 value1 :parameter2 value2 ... #+END:
OrgDynamicBlockWidget
An Org Mode dynamic block
OrgEntity
An entity, like \Omega
OrgEvents
A widget for managing callbacks invoked upon user interaction or other document-related events.
A link to a file, like
OrgFileLinkGrammarDefinition
Grammar rules for file links, which are basically a mini-format of their own
OrgFileLinkParserDefinition
File link parser definition
OrgFixedWidthArea
A fixed-width area, like
OrgFixedWidthAreaWidget
An Org Mode fixed-width area
OrgFootnote
A footnote, like
OrgFootnoteReference
A footnote reference, like [fn:1]
OrgFootnoteReferenceWidget
OrgFootnoteReferenceWidgetState
OrgGrammarDefinition
Top-level grammar definition
OrgHeadline
An Org headline, like
OrgHeadlineWidget
An Org Mode section headline
OrgHeadlineWidgetState
OrgHorizontalRule
A horizontal rule, like
OrgHorizontalRuleWidget
OrgInlineSrcBlock
An inline source block, like src_sh{echo "hello world"}
OrgInlineSrcBlockWidget
An Org Mode inline source block
OrgLatexBlock
A LaTeX block, like
OrgLatexBlockWidget
An Org Mode LaTeX block
OrgLatexInline
An inline LaTeX snippet, like $E=mc^2$
OrgLatexInlineWidget
An Org Mode LaTeX inline span
OrgLeafNode
OrgLinkTarget
A link target, like
OrgLinkTargetWidget
OrgLinkTargetWidgetState
OrgLinkWidget
A widget to display an OrgLink.
OrgList
A list, like
OrgListItem
OrgListOrderedItem
An ordered list item, like
OrgListUnorderedItem
An unordered list item, like
OrgListWidget
An Org Mode list
OrgLocalVariables
OrgLocalVariablesWidget
An Org Local Variables block
OrgLocator
A class facilitating locating elements within the document. It is optional; when not supplied, touching e.g. a footnote reference to jump to the footnote will do nothing.
OrgLocatorData
OrgMacroReference
A macro reference, like
OrgMarkup
Emphasis markup, like
OrgMeta
A "meta" line, like
OrgMetaWidget
An Org Mode meta line
OrgMetaWidgetState
OrgNode
The base type of all Org AST objects
OrgParagraph
OrgParagraphWidget
An Org Mode paragraph
OrgParentNode
OrgParserDefinition
Top-level parser definitions
OrgPgpBlock
OrgPgpBlockWidget
An Org PGP block
A link, like
OrgPlainText
Plain text that has no markup
OrgPlainTextSerializer
OrgPlanningEntry
A planning line, like
OrgPlanningKeyword
A planning keyword, like SCHEDULED: or DEADLINE:
OrgProperty
A property in a drawer, like
OrgPropertyWidget
An Org Mode property
OrgQueryAndMatcher
OrgQueryGrammarDefinition
Grammar rules for the section query language described at https://orgmode.org/manual/Matching-tags-and-properties.html
OrgQueryMatcher
A matcher for displaying the document as a "sparse tree" as in org-match-sparse-tree
OrgQueryNotMatcher
OrgQueryOrMatcher
OrgQueryParserDefinition
OrgQueryPropertyMatcher
OrgQueryTagMatcher
A word linkified to point to a radio target. This can only appear in a parsed tree if radio targets were supplied to the parser.
OrgRadioTarget
A link target, like
OrgRadioTargetWidget
OrgRadioTargetWidgetState
OrgRootWidget
A widget that sits above the OrgDocumentWidget and orchestrates OrgTheme and OrgEvents.
OrgSection
An Org section. May have nested sections, like
OrgSectionWidget
An Org Mode section
OrgSerializer
A class for serializing Org AST objects to Org Mode markup. Subclass and supply to OrgNode.toMarkup to customize serialization.
OrgSettings
A collection of settings that affect the appearance of the document
OrgSimpleTimestamp
A timestamp, like [2020-05-05 Tue]
OrgSrcBlock
A source block, like
OrgStatisticsCookie
OrgStatisticsFractionCookie
OrgStatisticsPercentageCookie
OrgSubscript
OrgSubscriptWidget
An Org subscript
OrgSubSuperscript
OrgSuperscript
OrgSuperscriptWidget
An Org superscript
OrgTable
A table, like
OrgTableCell
OrgTableCellRow
OrgTableDividerRow
OrgTableRow
OrgTableWidget
An Org Mode table
OrgText
Display an Org Mode document with minimal interaction, suitable for use as a rich equivalent to a Text widget.
OrgTheme
The theme for the Org Mode document
OrgThemeData
OrgTimeRangeTimestamp
OrgTimestamp
OrgTimestampModifier
OrgTodoStates
A class representing the TODO states a la org-todo-keywords. Extract such states embedded in a document using extractTodoSettings.
OrgTranscludeWidget
OrgTree
A node potentially containing OrgSections
Plist
PlistGrammar
PlistParser
TodoGrammar
TodoParser

Enums

OrgAttachDirType
OrgStyle
Supported styles for OrgMarkup nodes
OrgVisibilityState

Extensions

LayeredOrgSettings on List<OrgSettings>
OrgModifierUtils on DateTime
OrgTreeSearch on OrgTree
ZipperExt on ZipperLocation<ZR, ZI, ZS>

Constants

defaultTodoStates → const OrgTodoStates
kInlineTaskMinLevel → const int

Properties

org → Parser
The top-level Org parser
final
File link parser
final
orgPlist → Parser
final
orgQuery → Parser
final
orgTodo → Parser
final

Functions

extractRadioTargets(OrgTree tree) → Set<String>
Extracts the radio targets from the given tree.
extractTodoSettings(OrgTree tree) → List<OrgTodoStates>
Extracts the TODO settings from #+TODO: and equivalent meta keywords in the given tree.
isCoderefSearch(String query) → bool
Identify queries that point to code references, like (ref:my-function).
isLineNumberSearch(String query) → bool
Identify queries that are line numbers (positive integers).
isOrgCustomIdSearch(String query) → bool
Identify queries that point to a custom ID (starting with '#').
isOrgIdSearch(String query) → bool
Identify queries that point to IDs (starting with 'id:').
isOrgLocalSectionSearch(String query) → bool
Identify queries that point to a section within the current document (starting with '*')
isRegexpSearch(String query) → bool
Identify queries that are regular expressions, delimited by slashes.
looksLikeImagePath(String text) → bool
looksLikeUrl(String text) → bool
orgId() → String
Generate a random ID for an Org node. Use this when creating a new node based on an existing node with copyWith, where both nodes will be present in the tree at the same time.
parseCoderefSearch(String query) → String
Return the code reference name pointed to by the query. The query must be one for which isCoderefSearch returns true.
parseLineNumberSearch(String query) → int
Return the line number pointed to by the query. The query must be one that isLineNumberSearch returns true for.
parseOrgCustomIdSearch(String query) → String
Return the CUSTOM_ID of the section pointed to by the query. The query must be one for which isOrgCustomIdSearch returns true.
parseOrgIdSearch(String query) → String
Return the ID of the section pointed to by the query. The query must be one for which isOrgCustomIdSearch returns true.
parseOrgLocalSectionSearch(String query) → String
Return the title of the section pointed to by the query. The query must be one for which isOrgLocalSectionSearch returns true.
parseRegexpSearch(String query) → String
Return the regular expression pattern pointed to by the query. The query must be one that isRegexpSearch returns true for.