Org class

Display an Org Mode document with full interaction.

This is the default entrypoint for org_flutter. It composes its own OrgController, OrgRootWidget, and OrgDocumentWidget. For advanced use cases you may want to arrange these on your own.

Inheritance

Constructors

Org(String text, {TextStyle? style, OrgThemeData? lightTheme, OrgThemeData? darkTheme, OrgSettings? settings, void onLinkTap(OrgLink)?, void onLocalSectionLinkTap(OrgTree, {String? searchOption})?, void onSectionLongPress(OrgSection)?, List<Widget> onSectionSlide(OrgSection)?, void onListItemTap(OrgListItem)?, void onCitationTap(OrgCitation)?, void onTimestampTap(OrgNode)?, Widget? loadImage(OrgLink)?, Widget loadTransclusion(OrgMeta)?, String? restorationId, Key? key})
const

Properties

darkTheme → OrgThemeData?
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lightTheme → OrgThemeData?
final
loadImage → Widget? Function(OrgLink)?
A callback invoked when an image should be displayed. The argument is the OrgLink describing where the image data can be found. It is your responsibility to resolve the link, fetch the data, and return a widget for displaying the image.
final
loadTransclusion → Widget Function(OrgMeta)?
A callback invoked when loading transcluded content. The argument is the OrgMeta describing the transclusion. It is your responsibility to resolve the link, if present, fetch the data, and return a widget for displaying the transcluded content.
final
onCitationTap → void Function(OrgCitation)?
A callback invoked when the user taps on a citation.
final
onLinkTap → void Function(OrgLink)?
A callback invoked when the user taps a link. The argument is the OrgLink object; the URL is OrgLink.location. You might want to open this in a browser.
final
onListItemTap → void Function(OrgListItem)?
A callback invoked when the user taps on a list item that has a checkbox within the current document. The argument is the tapped item. You might want to toggle the checkbox.
final
onLocalSectionLinkTap → void Function(OrgTree, {String? searchOption})?
A callback invoked when the user taps on a link to a section within the current document. The argument is the target section. You might want to display it somehow. If the link to the section included a search option, it will be included as searchOption.
final
onSectionLongPress → void Function(OrgSection)?
A callback invoked when the user long-presses on a section headline within the current document. The argument is the pressed section. You might want to narrow the display to show just this section.
final
onSectionSlide → List<Widget> Function(OrgSection)?
A callback invoked to build a list of actions revealed when the user slides a section. The argument is the section being slid. Consider supplying instances of SlidableAction from the flutter_slidable package.
final
onTimestampTap → void Function(OrgNode)?
A callback invoked when the user taps on a timestamp.
final
restorationId → String?
An ID for temporary state restoration. Supply a unique ID to ensure that temporary state such as scroll position is preserved as appropriate.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
settings → OrgSettings?
A collection of settings that affect the appearance of the document
final
style → TextStyle?
Text style to serve as a basis for all text in the document
final
text → String
Raw Org Mode document in text form
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<Org>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited