OrgContent class

A generic node that contains children

Inheritance

Constructors

OrgContent(Iterable<OrgNode> children, [String? id])

Properties

children → List<OrgNode>
The children of this node. May be empty (no children) or null (an object that can't have children).
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
A unique ID for this node. Use this to identify nodes across edits via OrgTree.edit, because OrgParentNodes can be recreated and thus will not be equal via identical.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

contains(Pattern pattern) → bool
Return true if this node or any of its children recursively match the supplied pattern
override
copyWith({List<OrgNode>? children, String? id}) → OrgContent
edit() → OrgZipper
Obtain a zipper starting at the root of this node. The zipper can be used to edit the node; call ZipperLocation.commit to obtain a new node with the edits applied.
inherited
editNode(OrgNode node) → OrgZipper?
Obtain a zipper for the specified node, which is presumed to be a descendant of this node. Returns null if the node is not found. The zipper can be used to edit this node; call ZipperLocation.commit to obtain a new node with the edits applied.
inherited
ensureTrailingNewLine() → OrgContent
find<T extends OrgNode>(bool predicate(T), [OrgPath path = const []]) → ({T node, OrgPath path})?
Find the first node in the AST that satisfies predicate. Specify a type T to only visit nodes of that type. Returns a tuple of the node and its path from the root of the tree, or null if no node is found.
inherited
fromChildren(List<OrgNode> children) → OrgContent
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMarkup({OrgSerializer? serializer}) → String
inherited
toPlainText({OrgPlainTextSerializer? serializer}) → String
inherited
toString() → String
A string representation of this object.
override
visit<T extends OrgNode>(bool visitor(T)) → bool
Walk AST with visitor. Specify a type T to only visit nodes of that type. The visitor function must return true to continue iterating, or false to stop.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited