OrgInlineSrcBlock class

An inline source block, like src_sh{echo "hello world"}

Inheritance

Constructors

OrgInlineSrcBlock(String leading, String language, String? arguments, String body)

Properties

arguments → String?
final
body → String
final
children → List<OrgNode>?
The children of this node. May be empty (no children) or null (an object that can't have children).
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
language → String
final
leading → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

contains(Pattern pattern) → bool
Return true if this node or any of its children recursively match the supplied pattern
override
find<T extends OrgNode>(bool predicate(T), [OrgPath path = const []]) → ({T node, OrgPath path})?
Find the first node in the AST that satisfies predicate. Specify a type T to only visit nodes of that type. Returns a tuple of the node and its path from the root of the tree, or null if no node is found.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMarkup({OrgSerializer? serializer}) → String
inherited
toPlainText({OrgPlainTextSerializer? serializer}) → String
inherited
toString() → String
A string representation of this object.
inherited
visit<T extends OrgNode>(bool visitor(T)) → bool
Walk AST with visitor. Specify a type T to only visit nodes of that type. The visitor function must return true to continue iterating, or false to stop.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited