PlistParser class
Properties
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build()
→ Parser
-
Builds the default composite parser starting at
start.
inherited
-
buildFrom<T>(Parser<T> parser)
→ Parser<T>
-
Builds a composite parser starting with the specified
parser.
inherited
-
element()
→ Parser
-
inherited
-
elements()
→ Parser
-
inherited
-
escapedChar()
→ Parser
-
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
start()
→ Parser
-
Returns the starting production of this definition.
override
-
string()
→ Parser
-
override
-
stringChar()
→ Parser
-
inherited
-
stringContent()
→ Parser
-
override
-
symbol()
→ Parser
-
override
-
toString()
→ String
-
A string representation of this object.
inherited